@@ -180,6 +180,8 @@
 	i(GLUT_GAME_MODE_DISPLAY_CHANGED)
 #endif
 	/* FreeGLUT Constants */
+	i(GLUT_INIT_STATE)
+	i(GLUT_WINDOW_FORMAT_ID)
 	i(GLUT_ACTION_EXIT)
 	i(GLUT_ACTION_GLUTMAINLOOP_RETURNS)
 	i(GLUT_ACTION_CONTINUE_EXECUTION)
